--[[
Description: This plugin is part of the "Titan Panel [Currencies] Multi" addon. It shows your amount of Artifact Power.
Site: http://www.curse.com/addons/wow/titan-panel-currencies-multi
Author: Canettieri
Special Thanks to Eliote.
--]]

local ADDON_NAME, L = ...;
local ACE = LibStub("AceLocale-3.0"):GetLocale("Titan", true)
local version = GetAddOnMetadata(ADDON_NAME, "Version")
local ID = "TITAN_ARTFTM"
local ICON = "Interface\\Icons\\inv_scroll_05"
local artifactCount
local artifactTotalCount
local artifactMaximum
local artifactLevel
local artifactSpend
local weaponName
local artifactIcon
local artifactKnowledge
-----------------------------------------------
local function getInfo()
	local followerShipments = C_Garrison.GetLooseShipments(LE_GARRISON_TYPE_7_0);

  if not followerShipments then return end

	for i = 1, #followerShipments do
		local name, texture, shipmentCapacity, shipmentsReady, shipmentsTotal, creationTime, duration, timeleftString, _, _, _, followerID = C_Garrison.GetLandingPageShipmentInfoByContainerID(followerShipments[i]);
		if followerID == 139390 then
			return name, texture, shipmentCapacity, shipmentsReady, shipmentsTotal, creationTime, duration, timeleftString, _, _, _, followerID
		end
	end
end
-----------------------------------------------
local function UpdateAll(self)
	if HasArtifactEquipped() then
    local itemID, altItemID, name, icon, totalXP, pointsSpent, quality, artifactAppearanceID, appearanceModID, itemAppearanceID, altItemAppearanceID, altOnTop = C_ArtifactUI.GetEquippedArtifactInfo();
    local numPointsAvailableToSpend, xp , xpForNextPoint = MainMenuBar_GetNumArtifactTraitsPurchasableFromXP(pointsSpent, totalXP);
    local _, amount, texturePath, earnedThisWeek, weeklyMax, totalMax, isDiscovered, quality = GetCurrencyInfo(1171);

    artifactCount = xp
    artifactTotalCount = totalXP
    artifactMaximum = xpForNextPoint
    artifactLevel = pointsSpent
    artifactSpend = numPointsAvailableToSpend
    weaponName = name
    artifactKnowledge = amount
    artifactIcon = icon
  end

	if TitanPlugins[self.registry.id] and artifactIcon then
  	TitanPlugins[self.registry.id].icon = artifactIcon
  end

	TitanPanelButton_UpdateButton(self.registry.id)
end
-----------------------------------------------
local eventsTable = {
--	ARTIFACT_UPDATE = UpdateAll,
	ARTIFACT_XP_UPDATE = UpdateAll,
--	BAG_UPDATE = UpdateAll, -- Atualização da Bolsa
	PLAYER_EQUIPMENT_CHANGED = UpdateAll, -- Atualização de Equipamento
--	UNIT_DAMAGE = UpdateAll, -- Atualização da Arma
	ACTIVE_TALENT_GROUP_CHANGED = UpdateAll, -- Atualização da Árvore de Talentos
	PLAYER_ENTERING_WORLD = UpdateAll, -- Jogador entra no Mundo
	CURRENCY_DISPLAY_UPDATE = UpdateAll,
--	GARRISON_TALENT_COMPLETE = UpdateAll,
--	GARRISON_LANDINGPAGE_SHIPMENTS = UpdateAll,
--	GARRISON_SHIPMENT_RECEIVED = UpdateAll,
--	GARRISON_TALENT_UPDATE = UpdateAll
}
-----------------------------------------------
local function GetButtonText(self, id)
	if HasArtifactEquipped() then

		local researchname, texture, shipmentCapacity, shipmentsReady, shipmentsTotal, creationTime, duration, timeleftString, _, _, _, followerID = getInfo()

		local XP = (formatNumber(artifactCount, '.'))
		local tolvl = (formatNumber(artifactMaximum, '.'))
		local diff = (formatNumber(artifactMaximum - artifactCount, '.'))

		local weaponlvl = ""
		if artifactSpend == 0 or nil then
			weaponlvl = artifactLevel
		elseif
			artifactSpend > 0 then
				weaponlvl = artifactLevel.."|cFFFFFFFF-|cFFFF2e2e"..artifactSpend.."|r"
			end

		local porcentagem = (artifactCount * 100 / artifactMaximum)

		local hasTimeleft = timeleftString
		if not timeleftString then
			hasTimeleft = L["unknown"]
		end

		local knowledgeText = ""
		if researchname then
			knowledgeText = "   |TInterface\\Icons\\inv_scroll_11:0|t |cFFFFFFFF[|r|cffe6cc80"..artifactKnowledge.."|r|cFFFFFFFF]|cFF69FF69 "..shipmentsReady.."|r|||cFFFF2e2e"..shipmentsTotal.." |r|cFFFFFFFF(|r"..hasTimeleft.."|cFFFFFFFF)"
		elseif TitanGetVar(id, "HideKnowledge") then
			knowledgeText = ""
		end

			if not TitanGetVar(id, "SimpleText") then
				return L["ArticaftTitle"]..": ", "|cFFFFFFFF[|r|cFF198ae0"..weaponlvl.."|cFFFFFFFF]|r|cFF69FF69 "..XP.."|r|||cFFFFFFFF"..tolvl.." |cFFFF2e2e("..diff..")|r |cFFFFFFFF[|cFF69FF69"..(string.format("%.1f", porcentagem)).."%|r|cFFFFFFFF]"..knowledgeText
			else
				return L["ArticaftTitle"]..": ", "|cFF69FF69"..XP.."|r|||cFFFFFFFF"..tolvl
			end

		else
			return L["noweapon"]
		end
	end
-----------------------------------------------
local function GetTooltipText(self, id)
	UpdateAll(self)

	if HasArtifactEquipped() then
		local resname, texture, shipmentCapacity, shipmentsReady, shipmentsTotal, creationTime, duration, timeleftString, _, _, _, followerID = getInfo()
		local artifactInfoText = L["info"]..L["ArticaftLevel"]..artifactLevel.."|r\r"..L["ArticaftSpend"]..(formatNumber(artifactSpend, '.')).."|r\r"..L["ArticaftXP"]..(formatNumber(artifactCount, '.')).."|r\r"..L["ArticafttoMaximum"]..(formatNumber(artifactMaximum, '.')).."|r\r"..L["ArticafttoLvL"]..(formatNumber(artifactMaximum - artifactCount, '.'))

		local hasTimeleftttp = timeleftString
		if not timeleftString then
			hasTimeleftttp = L["unknown"]
		end

		local knowledgeToottipText = ""
		if resname then
			knowledgeToottipText = "\r\r".."["..resname.."]|r\r"..L["ArticaftKnowledge"]..artifactKnowledge.."|r\r"..L["researchOn"]..shipmentsReady.."/"..shipmentsTotal.."|r\r"..L["nextResearch"]..hasTimeleftttp
		end

		local tooltiptext = "\r\r"..artifactInfoText..knowledgeToottipText

		local hint = L["hint"]
		if TitanGetVar(id, "HideHint") then
			hint = ""
		end

		return hint.."|T"..artifactIcon..":0|t |cFFe6cc80"..weaponName.."|r"..tooltiptext
	else
		return L["noweaponttp"]
	end
end
-----------------------------------------------
local function PrepareMenu(self, id)
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[id].menuText)
	TitanPanelRightClickMenu_AddToggleIcon(id)
	TitanPanelRightClickMenu_AddToggleLabelText(id)

	local info = UIDropDownMenu_CreateInfo();
	info.text = L["simpleText"];
	info.func = function() TitanToggleVar(id, "SimpleText"); TitanPanelButton_UpdateButton(id); end
	info.checked = TitanGetVar(id, "SimpleText");
	Lib_UIDropDownMenu_AddButton(info);

	local info = UIDropDownMenu_CreateInfo();
	info.text = L["hidehint"];
	info.func = function() TitanToggleVar(id, "HideHint"); TitanPanelButton_UpdateButton(id); end
	info.checked = TitanGetVar(id, "HideHint");
	Lib_UIDropDownMenu_AddButton(info);

	local info = UIDropDownMenu_CreateInfo();
	info.text = L["hideknowledge"];
	info.func = function() TitanToggleVar(id, "HideKnowledge"); TitanPanelButton_UpdateButton(id); end
	info.checked = TitanGetVar(id, "HideKnowledge");
	Lib_UIDropDownMenu_AddButton(info);

	local info = UIDropDownMenu_CreateInfo();
	info.text = ACE["TITAN_CLOCK_MENU_DISPLAY_ON_RIGHT_SIDE"];
	info.func = function() TitanToggleVar(id, "DisplayOnRightSide"); TitanPanel_InitPanelButtons(id); end
	info.checked = TitanGetVar(id, "DisplayOnRightSide");
	Lib_UIDropDownMenu_AddButton(info);

	TitanPanelRightClickMenu_AddSpacer()
	TitanPanelRightClickMenu_AddCommand(ACE["TITAN_PANEL_MENU_HIDE"], id, TITAN_PANEL_MENU_FUNC_HIDE);
end
-----------------------------------------------
local function OnClick(self, button)
	if (button == "LeftButton") then
		SocketInventoryItem(16);
	end
end
-----------------------------------------------
L.Elib({
	id = ID,
	name = L["mLegion"].." Titan|cFF66b1ea "..L["ArticaftTitle"].."|r",
	tooltip = L["ArticaftTitle"],
	icon = ICON,
	category = "Information",
	version = version,
	onClick = OnClick,
	getButtonText = GetButtonText,
	eventsTable = eventsTable,
	getTooltipText = GetTooltipText,
	prepareMenu = PrepareMenu,
	onUpdate = function() TitanPanelButton_UpdateButton(ID) end,
	savedVariables = {
		ShowIcon = 1,
		DisplayOnRightSide = false,
		ShowLabelText = false,
		SimpleText = false,
		HintText = false,
		HideKnowledge = false,
	}
})
